PersonalizedPageRankAnchorSearcher
==================================

.. currentmodule:: pykeen.nn.node_piece

.. autoclass:: PersonalizedPageRankAnchorSearcher
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~PersonalizedPageRankAnchorSearcher.__call__
      ~PersonalizedPageRankAnchorSearcher.iter_extra_repr
      ~PersonalizedPageRankAnchorSearcher.precalculate_anchor_ppr

   .. rubric:: Methods Documentation

   .. automethod:: __call__
   .. automethod:: iter_extra_repr
   .. automethod:: precalculate_anchor_ppr
